from setuptools import setup

setup(
    name='mac-tag',
    version='2020.3.25',
    install_requires=[
        'public',
        'runcmd',
        'setuptools',
        'values',
    ],
    packages=[
        'mac_tag',
    ],
)
